@@ -7,9 +7,9 @@ import vtk.*;
 public class vtkOpenGLActor extends vtkActor
 {
 
-  private native String GetClassName_0();
-  public String GetClassName()
-    { return GetClassName_0(); }
+  private native int IsTypeOf_0(String id0);
+  public int IsTypeOf(String id0)
+    { return IsTypeOf_0(id0); }
 
   private native int IsA_1(String id0);
   public int IsA(String id0)
@@ -19,6 +19,14 @@ public class vtkOpenGLActor extends vtkActor
   public void Render(vtkRenderer id0,vtkMapper id1)
     { Render_2(id0,id1); }
 
+  private native long GLDepthMaskOverride_3();
+  public vtkInformationIntegerKey GLDepthMaskOverride() {
+    long temp = GLDepthMaskOverride_3();
+
+    if (temp == 0) return null;
+    return (vtkInformationIntegerKey)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
+}
+
   public vtkOpenGLActor() { super(); }
 
   public vtkOpenGLActor(long id) { super(id); }
