@@ -7,9 +7,9 @@ import vtk.*;
 public class vtkTableToSQLiteWriter extends vtkTableToDatabaseWriter
 {
 
-  private native String GetClassName_0();
-  public String GetClassName()
-    { return GetClassName_0(); }
+  private native int IsTypeOf_0(String id0);
+  public int IsTypeOf(String id0)
+    { return IsTypeOf_0(id0); }
 
   private native int IsA_1(String id0);
   public int IsA(String id0)
@@ -21,7 +21,7 @@ public class vtkTableToSQLiteWriter extends vtkTableToDatabaseWriter
 
     if (temp == 0) return null;
     return (vtkTable)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
-  }
+}
 
   private native long GetInput_3(int id0);
   public vtkTable GetInput(int id0) {
@@ -29,7 +29,7 @@ public class vtkTableToSQLiteWriter extends vtkTableToDatabaseWriter
 
     if (temp == 0) return null;
     return (vtkTable)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
-  }
+}
 
   public vtkTableToSQLiteWriter() { super(); }
 
